@@ -3,7 +3,7 @@
 /***********************************************************************
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
-*  Copyright (C) 2012-2013 Andrew Makhorin, Department for Applied
+*  Copyright (C) 2012-2017 Andrew Makhorin, Department for Applied
 *  Informatics, Moscow Aviation Institute, Moscow, Russia. All rights
 *  reserved. E-mail: <mao@gnu.org>.
 *
@@ -21,6 +21,10 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "cfg.h"
 #include "env.h"
 #include "prob.h"
@@ -197,7 +201,11 @@
 struct term { int ind; double val; };
 /* term a[j] * z[j] used to sort a[j]'s */
 
+#ifndef __WOE__
 static int fcmp(const void *e1, const void *e2)
+#else
+static int __cdecl fcmp(const void *e1, const void *e2)
+#endif
 {     /* auxiliary routine called from qsort */
       const struct term *t1 = e1, *t2 = e2;
       if (t1->val > t2->val)
