@@ -4,9 +4,9 @@
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-*  2009, 2010, 2011, 2013, 2014, 2015, 2016 Andrew Makhorin, Department
-*  for Applied Informatics, Moscow Aviation Institute, Moscow, Russia.
-*  All rights reserved. E-mail: <mao@gnu.org>.
+*  2009, 2010, 2011, 2013, 2014, 2015, 2016, 2017 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@gnu.org>.
 *
 *  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ extern "C" {
 
 /* library version numbers: */
 #define GLP_MAJOR_VERSION  4
-#define GLP_MINOR_VERSION  59
+#define GLP_MINOR_VERSION  61
 
 typedef struct glp_prob glp_prob;
 /* LP/MIP problem object */
@@ -728,39 +728,53 @@ int glp_ios_heur_sol(glp_tree *T, const double x[]);
 void glp_ios_terminate(glp_tree *T);
 /* terminate the solution process */
 
-#if 1 /* 06/III-2016; not documented yet */
+#ifdef GLP_UNDOC
 int glp_gmi_cut(glp_prob *P, int j, int ind[], double val[], double
       phi[]);
 /* generate Gomory's mixed integer cut (core routine) */
+#endif
 
+#ifdef GLP_UNDOC
 int glp_gmi_gen(glp_prob *P, glp_prob *pool, int max_cuts);
 /* generate Gomory's mixed integer cuts */
 #endif
 
-#if 1 /* 06/III-2016; not documented yet */
+#ifdef GLP_UNDOC
 typedef struct glp_mir glp_mir;
 /* MIR cut generator workspace */
+#endif
 
+#ifdef GLP_UNDOC
 glp_mir *glp_mir_init(glp_prob *P);
 /* create and initialize MIR cut generator */
+#endif
 
+#ifdef GLP_UNDOC
 int glp_mir_gen(glp_prob *P, glp_mir *mir, glp_prob *pool);
 /* generate mixed integer rounding (MIR) cuts */
+#endif
 
+#ifdef GLP_UNDOC
 void glp_mir_free(glp_mir *mir);
 /* delete MIR cut generator workspace */
 #endif
 
-#if 1 /* 08/III-2016; not documented yet */
+#ifdef GLP_UNDOC
 typedef struct glp_cfg glp_cfg;
 /* conflict graph descriptor */
+#endif
 
+#ifdef GLP_UNDOC
 glp_cfg *glp_cfg_init(glp_prob *P);
 /* create and initialize conflict graph */
+#endif
 
+#ifdef GLP_UNDOC
 void glp_cfg_free(glp_cfg *G);
 /* delete conflict graph descriptor */
+#endif
 
+#ifdef GLP_UNDOC
 int glp_clq_cut(glp_prob *P, glp_cfg *G, int ind[], double val[]);
 /* generate clique cut from conflict graph */
 #endif
@@ -836,6 +850,9 @@ int glp_init_env(void);
 const char *glp_version(void);
 /* determine library version */
 
+const char *glp_config(const char *option);
+/* determine library configuration */
+
 int glp_free_env(void);
 /* free GLPK environment */
 
