@@ -22,7 +22,7 @@
 ***********************************************************************/
 
 #include "mpl.h"
-#include "sql.h"
+#include "mplsql.h"
 
 /**********************************************************************/
 
